@@ -6,6 +6,7 @@ CONFIG_APPROVED_EDITS = "ckanext.comments.approved_edits"
 CONFIG_DRAFT_EDITS_BY_AUTHOR = "ckanext.comments.draft_edits_by_author"
 CONFIG_APPROVED_EDITS_BY_AUTHOR = "ckanext.comments.approved_edits_by_author"
 
+CONFIG_MOBILE_THRESHOLD = 'ckanext.comments.mobile_depth_threshold'
 
 DEFAULT_REQUIRE_APPROVAL = True
 
@@ -14,3 +15,5 @@ DEFAULT_APPROVED_EDITS = False
 
 DEFAULT_DRAFT_EDITS_BY_AUTHOR = False
 DEFAULT_APPROVED_EDITS_BY_AUTHOR = False
+
+DEFAULT_MOBILE_THRESHOLD = 3
